| Title: | Retrieve Information from 'Google Knowledge Graph' API |
|---|---|
| Description: | Allows you to retrieve information from the 'Google Knowledge Graph' API <https://www.google.com/intl/bn/insidesearch/features/search/knowledge.html> and process it in R in various forms. The 'Knowledge Graph Search' API lets you find entities in the 'Google Knowledge Graph'. The API uses standard 'schema.org' types and is compliant with the 'JSON-LD' specification. |
| Authors: | Daniel Schmeh |
| Maintainer: | Daniel Schmeh <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-06-02 06:56:26 UTC |
| Source: | https://github.com/cran/GoogleKnowledgeGraphR |
This function allows you to get the Information for a specific Keyword you enter. The output is a Dataframe with the Data retrived by the Google API.
gkg(query, token = "AIzaSyDsxs2vKm33doRABnW4JoieK8RrDQvJwds", language = "en", limit = 1, types = "", prefix = FALSE, type_output = TRUE)gkg(query, token = "AIzaSyDsxs2vKm33doRABnW4JoieK8RrDQvJwds", language = "en", limit = 1, types = "", prefix = FALSE, type_output = TRUE)
query |
The keyword you want to get the information for |
token |
The token for yor Google API Project. Please use your own token if you have a lot of querys. You can find additional informations about the token here: https://developers.google.com/knowledge-graph/prereqs |
language |
The list of language codes (defined in ISO 639) to run the query with. Default is "en" |
limit |
Limits the number of entities to be returned. The API-Limit is 20. |
types |
Restricts returned entities to those of the specified types. For example, you can specify Person (as defined in http://schema.org/Person) to restrict the results to entities representing people. If multiple types are specified, returned entities will contain one or more of these types. Default are all types. |
prefix |
Enables prefix (initial substring) match against names and aliases of entities. For example, a prefix Jung will match entities and aliases such as Jung, Jungle, and Jung-ho Kang. Default is FALSE. |
type_output |
In most cases, the API returns more than one type for a keyword. If type_output is set to TRUE, the types are placed in a cell. FALSE returns the list of types in a row. Default is TRUE. gkg() |
{ gkg("beer") }{ gkg("beer") }
This function allows you to get the Information for a specific Keyword you enter.
gkg_raw(query, token = "AIzaSyDsxs2vKm33doRABnW4JoieK8RrDQvJwds", language = "en", limit = 1, types = "", prefix = FALSE)gkg_raw(query, token = "AIzaSyDsxs2vKm33doRABnW4JoieK8RrDQvJwds", language = "en", limit = 1, types = "", prefix = FALSE)
query |
The keyword you want to get the information for |
token |
The token for yor Google API Project. Please use your own token if you have a lot of querys. You can find additional informations about the token here: https://developers.google.com/knowledge-graph/prereqs |
language |
The list of language codes (defined in ISO 639) to run the query with. Default is "en" |
limit |
Limits the number of entities to be returned. The API-Limit is 20. |
types |
Restricts returned entities to those of the specified types. For example, you can specify Person (as defined in http://schema.org/Person) to restrict the results to entities representing people. If multiple types are specified, returned entities will contain one or more of these types. Default are all types. |
prefix |
Enables prefix (initial substring) match against names and aliases of entities. For example, a prefix Jung will match entities and aliases such as Jung, Jungle, and Jung-ho Kang. Default is FALSE. gkg_raw() |
{ gkg_raw("beer") }{ gkg_raw("beer") }